"""website URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, include
from home.views import homePage
from rest_framework import routers, urls
from api.views import BalanceView, ImageView
from django.conf import settings
from django.conf.urls.static import static
from django.contrib.auth import views
from django.views.generic.base import TemplateView
from upload.views import uploadContent, imageUpload, viewMedia
from users.views import getBalance, addToBalance, adminView, removeBalance


router = routers.DefaultRouter()
router.register("balance", BalanceView, basename="balance")
router.register("images", ImageView, basename="image")

urlpatterns = [

    path("", homePage, name='home'),
    path("users/", include('django.contrib.auth.urls')),
    path('users/', include('users.urls')),
    # path("upload/", uploadContent, name="Upload"),
    path("upload/", imageUpload, name="Image"),
    # path("upload_video/", videoUpload, name="Video"),
    path("view_media/", viewMedia, name="All Media"),
    path("get_balance/",getBalance, name="Balance" ),
    path("add_balance/", addToBalance, name="Add"),
    path("remove_balance/", removeBalance, name="Add"),
    path("admin/", adminView, name="admin"),
    path('api/', include(router.urls))
    
]
if settings.DEBUG:
    urlpatterns += static(settings.MEDIA_URL,
                          document_root=settings.MEDIA_ROOT)
    urlpatterns += static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)

